\name{isoDu}
\alias{isoDu}
\title{
 Assess isoform differential usage between two groups
}
\description{
 Testing RNA isoform differential usage between two groups 
 (e.g. group A and group B) by parametric bootstrap
}
\usage{
isoDu(tags, Routs, xData, outputFileName, fragSizeFiles, g2test, 
  readLen, method=c("bootstrap", "permutation"), nlambda=10,  
  ntau=3, lmax=500, idxs=NULL, duOnly=FALSE, nBoots=10000, 
  pUpper=0.05, pConf=0.99, misAligns=rep(0.001, length(tags)),
  muMin = 0.01, maxTime=Inf, saveRData="", simulationPhi=NULL, 
  simuNULL=FALSE)
}
\arguments{
  \item{tags}{
  a character vector of the tags of the samples
}
  \item{Routs}{
  a character vector of the file names of the .Rout files of the 
  samples, which are gernated from function isoDetector.
}
  \item{xData}{
  data of the covariates of interest. xData could be a vector or a matrix. 
  If it is a vector, ith element is the valuae of the covariate for sample
  tags[i]. If it is a matrix, its i-th row corresponds to sample tags[i]. 
  p-value will be calcualted for each covariate in xData and both individaul
  p-values and smallest p-value will be returned. 
}
  \item{outputFileName}{
  the name of output file.
}
  \item{fragSizeFiles}{
  Names of the text files recording the distribution of the fragment lengths. 
  The file names should be one-to-one correspondence with the sampples 
  specified in tags. Each file should have 2 columns: 
  "Frequency" and "Length", without header. 
  For example:
  \verb{
	20546 75
	40465 76
	37486 77
	27533 78
	25344 79
	}
}
  \item{g2test}{
  the names of the transcript clusters to be tested.
}
  \item{readLen}{
  the length of a read, e.g., 75.
}
  \item{method}{
  Resampling method. Must be 'bootstrap' if sample size is smaller than 5.
}  
  \item{nlambda}{
	number of values of tuning parameter lambda. 
}
  \item{ntau}{
	number of values of tuning parameter tau. 
}
  \item{lmax}{
  maximum fragment length.
}
  \item{idxs}{
  by default, idxs is NULL and isoform differential usage is tested 
  across all transcription clusters. If idxs is not NULL, only the 
  transcript clusters specified in idxs are examined. 
}
  \item{duOnly}{
  If duOnly is FALSE, we simultaneously test differential expression and 
  differential isoform usage. The total number of reads of a sample is 
  calculated by adding up the number of reads for all the transcript clusters 
  listed in parameter g2test.
}
  \item{nBoots}{
  number of bootstraps. If nBoots <=0, no bootstraping will be done. 
}
  \item{pUpper}{
  stop the bootstrapig if we have \code{pConf} confidence that the p-value
  is larger than pUpper.
}
  \item{pConf}{
  see the explanation for \code{pConf}
}
  \item{misAligns}{
  the rate of mis-aligned sequences for samples in group A. This should be 
  a vector of the same length as tags. misAligns times sequence length 
  (in bps) is the effective length of a sequence due to alignment error.
}
  \item{muMin}{
  if mu=0, set it to muMin. This is used during GLM fitting for stability of  
  the algoirithm. It should be set to be the same value as is used by function 
  geneModel.
}
  \item{maxTime}{
  maximum amount of CPU time charged for execution by the system 
  (system time) for each transription cluster. When it reaches the 
  maxTime, the bootstrapping process is stopped.
}
  \item{saveRData}{
  if saveRData != "", the null and alternative model fitting results written 
  into RData file starting with the character specified by saveRData.
}
  \item{simulationPhi}{
  if !is.null(simulationPhi), carry out isoDU computation using simulated 
  data with over-dispersion parameter specified by simulationPhi.
}  
	\item{simuNULL}{
  if !is.null(simulationPhi), simuNULL specifies to simulate from null or 
  alternative distribution. If simulationPhi is NULL, simuNULL is not used.
}
}
\value{
Results are written into an output file with four columns
  \item{cluster }{ the name of the transcription cluster }
  \item{pval }{ non-nested Likelihood Ratio Test p-values, 
  	one p-value for each column of xData }
  \item{minPval }{ mininum of pval }
  \item{minPvalBoots }{ mininum pval evaluated by parametric bootstrap }
  \item{nBoots }{ Number of bootstrap }
}
\references{
  Sun et al. A statistical method for simultaneous isoform detection 
  and assessment of differential alternative expression
}
\author{ Wei Sun weisun@email.unc.edu }
\keyword{ methods }
